MICROBIOLOGY = [
    'actinobacteria',
    'adenovirus',
    'aerobe',
    'almeida',
    'anabiosis',
    'anaerobe',
    'antibiotics',
    'antigen',
    'antiseptics',
    'archeon',
    'bacillus',
    'bacteria',
    'bacteriophage',
    'bacterium',
    'baltimore',
    'beijerinck',
    'biofilm',
    'bioluminescence',
    'bioterrorism',
    'blumberg',
    'capsid',
    'capsomer',
    'capsomere',
    'capsule',
    'chickenpox',
    'coinfection',
    'coronavirus',
    'ebola',
    'endolysin',
    'endotoxin',
    'enterobacterales',
    'enterotoxin',
    'epidemiologist',
    'escherichia',
    'exotoxin',
    'fermentation',
    'flagellum',
    'fleming',
    'gallo',
    'gene',
    'genomes',
    'geomicrobiology',
    'herpesvirus',
    'hiv',
    'hosts',
    'immunity',
    'infection',
    'influenza',
    'ivanovsky',
    'koch',
    'lactobacillus',
    'leeuwenhoek',
    'loeffler',
    'lysin',
    'lysis',
    'mayer',
    'metagenome',
    'microbe',
    'microbiologist',
    'microbiology',
    'microbiome',
    'microbiota',
    'microorganism',
    'monod',
    'montagnier',
    'mutation',
    'mycovirus',
    'nucleocapsid',
    'oncovirus',
    'papillomavirus',
    'pasteur',
    'pathogen',
    'pathogenesis',
    'phage',
    'phagetherapy',
    'polymerases',
    'prophage',
    'protease',
    'proteins',
    'provirus',
    'receptor',
    'retrovirus',
    'rotavirus',
    'salk',
    'sarscov2',
    'serology',
    'spike',
    'stanley',
    'staphylococcus',
    'strains',
    'theiler',
    'transmission',
    'variant',
    'virion',
    'viroid',
    'virologist',
    'virome',
    'virulence',
    'viruses',
    'zikavirus',
    'zoonosis',

]
