COUNTRIES = [
    'afghanistan',
    'albania',
    'algeria',
    'andorra',
    'angola',
    'argentina',
    'armenia',
    'aruba',
    'australia',
    'austria',
    'azerbaijan',
    'bahamas',
    'bahrain',
    'bangladesh',
    'barbados',
    'belarus',
    'belgium',
    'belize',
    'benin',
    'bhutan',
    'bolivia',
    'botswana',
    'brazil',
    'brunei',
    'bulgaria',
    'burkina',
    'burundi',
    'cambodia',
    'cameroon',
    'canada',
    'capeverde',
    'chad',
    'chile',
    'china',
    'colombia',
    'comoros',
    'congo',
    'costarica',
    'croatia',
    'cuba',
    'curaco',
    'cyprus',
    'czechrepublic',
    'denmark',
    'djibouti',
    'dominica',
    'ecuador',
    'egypt',
    'elsalvador',
    'eritrea',
    'estonia',
    'eswatini',
    'ethiopia',
    'fiji',
    'finland',
    'france',
    'gabon',
    'gambia',
    'georgia',
    'germany',
    'ghana',
    'greece',
    'grenada',
    'guatemala',
    'guinea',
    'guineabissau',
    'guyana',
    'haiti',
    'honduras',
    'hungary',
    'iceland',
    'india',
    'indonesia',
    'iran',
    'iraq',
    'ireland',
    'israel',
    'italy',
    'ivorycoast',
    'jamaica',
    'japan',
    'jordan',
    'kazakhstan',
    'kenya',
    'kiribati',
    'kosovo',
    'kuwait',
    'kyrgyzstan',
    'laos',
    'latvia',
    'lebanon',
    'lesotho',
    'liberia',
    'libya',
    'liechtenstein',
    'lithuania',
    'luxembourg',
    'macedonia',
    'madagascar',
    'malawi',
    'malaysia',
    'maldives',
    'mali',
    'malta',
    'mauritania',
    'mauritius',
    'mexico',
    'micronesia',
    'moldova',
    'monaco',
    'mongolia',
    'montenegro',
    'morocco',
    'mozambique',
    'myanmar',
    'namibia',
    'nauru',
    'nepal',
    'netherlands',
    'newzealand',
    'nicaragua',
    'niger',
    'nigeria',
    'northkorea',
    'norway',
    'oman',
    'pakistan',
    'palau',
    'palestine',
    'panama',
    'paraguay',
    'peru',
    'philippines',
    'poland',
    'portugal',
    'qatar',
    'romania',
    'russia',
    'rwanda',
    'samoa',
    'saudiarabia',
    'senegal',
    'serbia',
    'seychelles',
    'sierraleone',
    'singapore',
    'slovakia',
    'slovenia',
    'solomonislands',
    'somalia',
    'southkorea',
    'spain',
    'srilanka',
    'sudan',
    'suriname',
    'sweden',
    'switzerland',
    'syria',
    'taiwan',
    'tajikistan',
    'tanzania',
    'thailand',
    'togo',
    'tonga',
    'tunisia',
    'turkey',
    'turkmenistan',
    'tuvalu',
    'uganda',
    'ukraine',
    'unitedkingdom',
    'unitedstates',
    'uruguay',
    'usa',
    'uzbekistan',
    'vanuatu',
    'vatican',
    'venezuela',
    'vietnam',
    'yemen',
    'zambia',
    'zimbabwe',

]
