CHEMISTRY = [
    'acid',
    'alkane',
    'alkene',
    'alkyne',
    'amide',
    'amine',
    'anion',
    'anode',
    'atoms',
    'autoionization',
    'avogadro',
    'barometer',
    'beaker',
    'bond',
    'calorie',
    'calorimeter',
    'calorimetry',
    'capillary',
    'carbanion',
    'carbon',
    'catalyst',
    'cathode',
    'charge',
    'chemical',
    'chemist',
    'chromatography',
    'colloid',
    'combustion',
    'compound',
    'concentration',
    'condensation',
    'conformations',
    'crystal',
    'curie',
    'decay',
    'decomposition',
    'detergent',
    'deuterium',
    'diffusions',
    'dilution',
    'dimer',
    'dipole',
    'dissociation',
    'distillation',
    'donor',
    'dosimeter',
    'effusion',
    'electrode',
    'electrolysis',
    'electrolyte',
    'electrons',
    'electrophile',
    'electrophoresis',
    'element',
    'emulsion',
    'enthalpy',
    'entropy',
    'equilibrium',
    'ester',
    'ether',
    'evaporization',
    'fission',
    'frequency',
    'gas',
    'gel',
    'halogen',
    'heat',
    'hydrate',
    'hydration',
    'hydrocarbon',
    'hydrolysis',
    'ion',
    'isotope',
    'kelvin',
    'ketone',
    'liquid',
    'mass',
    'mendeleev',
    'metalloids',
    'mixture',
    'molality',
    'molarity',
    'molecule',
    'moles',
    'neutralization',
    'neutrons',
    'nitrogen',
    'nucleon',
    'octet',
    'osmosis',
    'oxidation',
    'oxide',
    'particles',
    'pauling',
    'periodicity',
    'periods',
    'peroxide',
    'phase',
    'phenol',
    'pipette',
    'plasma',
    'polymer',
    'polymerization',
    'product',
    'protons',
    'raoult',
    'reactant',
    'reaction',
    'redox',
    'rutherford',
    'salt',
    'saponification',
    'silicones',
    'solute',
    'solution',
    'solvent',
    'stereoisomers',
    'stoichiometry',
    'sublimation',
    'substance',
    'temperature',
    'term',
    'thermodynamics',
    'vapor',
    'vaporization',
    'volatile',
    'volume',

]
