MUSIC = [
    'acappella',
    'accelerando',
    'adagio',
    'allegro',
    'alto',
    'andante',
    'aria',
    'arrangement',
    'audio',
    'bach',
    'balla',
    'ballet',
    'band',
    'banjo',
    'baritone',
    'bass',
    'bassoon',
    'beat',
    'beethoven',
    'bell',
    'blues',
    'bobdylan',
    'bobmarley',
    'bolero',
    'bongo',
    'brahms',
    'bryanadams',
    'bugle',
    'cadence',
    'canon',
    'cantata',
    'carlossantana',
    'celesta',
    'cello',
    'chant',
    'chimes',
    'chopin',
    'chorale',
    'chord',
    'chorus',
    'clarinet',
    'clef',
    'composer',
    'concerto',
    'contrabassoon',
    'contralto',
    'cornet',
    'cymbal',
    'cymbals',
    'czajkowski',
    'deanmartin',
    'diminution',
    'downbeat',
    'drum',
    'duet',
    'duple',
    'eltonjohn',
    'elvispresley',
    'eminem',
    'ensemble',
    'etude',
    'expressionism',
    'falsetto',
    'flute',
    'forte',
    'fortepiano',
    'fortissimo',
    'freddiemercury',
    'fugue',
    'gamelan',
    'georgemichael',
    'gong',
    'guitar',
    'habanera',
    'harmony',
    'harp',
    'harpsichord',
    'hiphop',
    'horn',
    'improvisation',
    'interval',
    'intro',
    'jimihendrix',
    'kettledrums',
    'key',
    'koto',
    'largo',
    'legato',
    'libretto',
    'lionelrichie',
    'lute',
    'madrigal',
    'marimba',
    'mazurka',
    'melody',
    'metallica',
    'mezzoforte',
    'mezzopiano',
    'michaeljackson',
    'minuet',
    'moderato',
    'modulation',
    'mozart',
    'mp3',
    'music',
    'mute',
    'nocturne',
    'notation',
    'note',
    'oboe',
    'octave',
    'opera',
    'orchestra',
    'overture',
    'philcollins',
    'pianissimo',
    'piano',
    'pianoforte',
    'piccolo',
    'pinkfloyd',
    'pitch',
    'polka',
    'polonaise',
    'polyphony',
    'prelude',
    'presto',
    'quartet',
    'quintet',
    'raga',
    'ragtime',
    'rap',
    'raycharles',
    'recital',
    'recorder',
    'recording',
    'refrain',
    'rehearsal',
    'requiem',
    'rhythm',
    'ritardando',
    'rock',
    'rodstewart',
    'rollingstones',
    'royorbison',
    'rubato',
    'sax',
    'saxophone',
    'schumann',
    'serenade',
    'shakuhachi',
    'snare',
    'sonata',
    'song',
    'soprano',
    'sousaphone',
    'steviewonder',
    'strauss',
    'string',
    'swing',
    'synthesizer',
    'tambourine',
    'tempo',
    'tenor',
    'thebeatles',
    'theme',
    'timpani',
    'tinaturner',
    'tone',
    'triplet',
    'trombone',
    'trumpet',
    'tuba',
    'tuning',
    'tupac',
    'vibes',
    'vibrato',
    'viola',
    'violin',
    'viruoso',
    'wagner',
    'waltz',
    'xylophone',

]
