MOLECULAR_BIOLOGY = [
    'adenine',
    'allele',
    'aminoacid',
    'amplicon',
    'antibody',
    'anticodon',
    'biochemistry',
    'bioenergetics',
    'bioinformatics',
    'biotechnology',
    'brenner',
    'cell',
    'centriole',
    'centrosome',
    'chromatid',
    'chromosome',
    'codon',
    'coenzyme',
    'complementation',
    'contig',
    'cosmid',
    'crick',
    'crossingover',
    'deletion',
    'deoxyribose',
    'diploid',
    'dna',
    'dynein',
    'electroporation',
    'endocytosis',
    'endonuclease',
    'enhancer',
    'enzyme',
    'epigenetics',
    'euchromatin',
    'exon',
    'exonuclease',
    'franklin',
    'geneexpression',
    'genes',
    'genome',
    'genomics',
    'haploid',
    'helicase',
    'heterochromatin',
    'heteroduplex',
    'hybridization',
    'hydrophil',
    'hydrophob',
    'immunoglobulin',
    'inhibitor',
    'insertion',
    'intron',
    'junkdna',
    'kimura',
    'kinase',
    'ligase',
    'lipoprotein',
    'loci',
    'luciferase',
    'lysogeny',
    'metabolomics',
    'microbes',
    'monosaccharide',
    'mrna',
    'mutations',
    'myosin',
    'nadp+',
    'nadph',
    'nucleolus',
    'nucleosome',
    'nucleotide',
    'oligonucleotide',
    'operon',
    'orf',
    'peptidoglycan',
    'plasmid',
    'polyadenylation',
    'polymerase',
    'polysaccharide',
    'primer',
    'probe',
    'promoter',
    'protein',
    'proteomics',
    'proteosome',
    'pyrimidine',
    'recombination',
    'replication',
    'restriction',
    'retrotransposon',
    'ribonuclease',
    'ribosome',
    'rna',
    'sequencing',
    'splicing',
    'supercoil',
    'superinfection',
    'taqpolymerase',
    'telomerase',
    'telomere',
    'terminator',
    'thymine',
    'topoisomerase',
    'transcriptase',
    'transcription',
    'transduction',
    'translation',
    'transposon',
    'trna',
    'ubiquitin',
    'uracil',
    'vectors',
    'venter',
    'virology',
    'virusoid',
    'watson',
    'westernblot',

]
