GEOGRAPHY = [
    'afforestation',
    'agriculture',
    'alluvium',
    'altitude',
    'anemometer',
    'antarctic',
    'anticyclone',
    'archipelago',
    'atlas',
    'atmosphere',
    'atoll',
    'azimuth',
    'bay',
    'beach',
    'biodiversity',
    'biosphere',
    'border',
    'butte',
    'caldera',
    'canal',
    'canyon',
    'cape',
    'capital',
    'cartogram',
    'cartography',
    'cave',
    'channel',
    'chart',
    'cimate',
    'city',
    'cliff',
    'cloud',
    'compass',
    'continent',
    'contour',
    'coordinates',
    'corrasion',
    'corrosion',
    'country',
    'cove',
    'crust',
    'cumulonimbus',
    'cumulus',
    'cyclone',
    'deflation',
    'degrees',
    'delta',
    'depression',
    'desert',
    'desertification',
    'drainage',
    'drift',
    'drought',
    'dune',
    'earthquake',
    'east',
    'ecosystems',
    'elevation',
    'emigration',
    'environment',
    'equator',
    'erosion',
    'escarpment',
    'estuary',
    'exfoliation',
    'fjord',
    'front',
    'geolocalization',
    'geyser',
    'glaciation',
    'glacier',
    'globalization',
    'globe',
    'gps',
    'granite',
    'groundwater',
    'gulf',
    'habitat',
    'hemisphere',
    'hill',
    'horizon',
    'hurricane',
    'hydrosphere',
    'hygrometer',
    'iceberg',
    'immigration',
    'industrialization',
    'ionospheres',
    'island',
    'isobar',
    'isohyet',
    'isotherm',
    'laccolith',
    'lagoon',
    'lake',
    'land',
    'landform',
    'latitude',
    'lava',
    'legend',
    'limestone',
    'location',
    'longitude',
    'magma',
    'map',
    'marble',
    'marsh',
    'meander',
    'meridian',
    'mesa',
    'moraine',
    'mortlake',
    'mountain',
    'nation',
    'north',
    'oasis',
    'ocean',
    'ozone',
    'pangaea',
    'parallel',
    'passage',
    'peak',
    'peninsula',
    'permafrost',
    'plain',
    'plateau',
    'pole',
    'pollution',
    'pond',
    'population',
    'pothole',
    'prairie',
    'pyroclasts',
    'quartz',
    'rain',
    'reef',
    'region',
    'reservoir',
    'resource',
    'river',
    'rocks',
    'savanna',
    'scale',
    'sea',
    'sediment',
    'seismograph',
    'seismology',
    'sill',
    'smog',
    'soil',
    'solifluction',
    'sound',
    'source',
    'south',
    'spring',
    'stalactite',
    'stalagmite',
    'strait',
    'strata',
    'stratosphere',
    'stratus',
    'swamp',
    'swash',
    'taiga',
    'terracing',
    'territory',
    'tides',
    'topography',
    'tornado',
    'tributary',
    'tropics',
    'tsunami',
    'tundra',
    'typhoon',
    'urbanization',
    'valley',
    'volcano',
    'waterfall',
    'waves',
    'weather',
    'west',
    'wetland',
    'world',

]
