ADJECTIVES = [
    'abandoned',
    'abashed',
    'aberrant',
    'abhorrent',
    'abiding',
    'abject',
    'ablaze',
    'able',
    'abounding',
    'abrasive',
    'abrupt',
    'absent',
    'absolute',
    'absorbed',
    'absorbing',
    'abstract',
    'abstracted',
    'absurd',
    'abundant',
    'academic',
    'acceptable',
    'accepted',
    'accepting',
    'accessible',
    'accidental',
    'accurate',
    'accused',
    'ace',
    'achromatic',
    'acidic',
    'acoustic',
    'acrid',
    'actionable',
    'active',
    'actual',
    'acute',
    'acyclic',
    'adamant',
    'adaptable',
    'adapting',
    'adaptive',
    'added',
    'additional',
    'adept',
    'adequate',
    'adhesive',
    'adiabatic',
    'adjacent',
    'adjoining',
    'adjusted',
    'administrative',
    'admiring',
    'adorable',
    'adoring',
    'adroit',
    'advanced',
    'adventurous',
    'adverse',
    'advisory',
    'aesthetic',
    'affable',
    'affectionate',
    'afraid',
    'aged',
    'aggregate',
    'aggressive',
    'agile',
    'agitated',
    'agonizing',
    'agreeable',
    'agreed',
    'agricultural',
    'airy',
    'alert',
    'alive',
    'all',
    'alleged',
    'allegro',
    'allied',
    'allowing',
    'alluring',
    'alone',
    'aloof',
    'alright',
    'alternate',
    'alternating',
    'alternative',
    'amateur',
    'amazed',
    'amazing',
    'amber',
    'ambiguous',
    'ambitious',
    'amiable',
    'amicable',
    'amortized',
    'ample',
    'amused',
    'amusing',
    'ancient',
    'andante',
    'angry',
    'animated',
    'animato',
    'annoyed',
    'annoying',
    'annual',
    'anonymous',
    'another',
    'antique',
    'anxious',
    'apathetic',
    'appalling',
    'apparent',
    'applicable',
    'appropriate',
    'approximate',
    'aquamarine',
    'aquatic',
    'arbitrary',
    'archaic',
    'architectural',
    'arctic',
    'ardent',
    'arid',
    'armed',
    'aromatic',
    'arriving',
    'arrogant',
    'artificial',
    'artistic',
    'ascent',
    'ashamed',
    'asleep',
    'asphalt',
    'aspiring',
    'assistant',
    'associated',
    'associative',
    'assorted',
    'assured',
    'assuring',
    'astonishing',
    'astute',
    'asymptotic',
    'atomic',
    'attractive',
    'auburn',
    'augmenting',
    'august',
    'auspicious',
    'automatic',
    'autonomous',
    'available',
    'average',
    'avid',
    'avocado',
    'awaited',
    'awake',
    'aware',
    'awesome',
    'awful',
    'awkward',
    'axiomatic',
    'azure',
    'back',
    'backstabbing',
    'bad',
    'baked',
    'balanced',
    'balmy',
    'barbarous',
    'bare',
    'bashful',
    'basic',
    'bawdy',
    'beautiful',
    'becoming',
    'befitting',
    'beige',
    'belligerent',
    'beloved',
    'beneficial',
    'benevolent',
    'bent',
    'berserk',
    'best',
    'better',
    'beveled',
    'bewildered',
    'big',
    'billowing',
    'billowy',
    'binary',
    'binding',
    'biological',
    'bipartite',
    'bisque',
    'bitter',
    'bizarre',
    'bizzare',
    'black',
    'bland',
    'blank',
    'blaring',
    'blazing',
    'blended',
    'blessed',
    'blind',
    'blistering',
    'blocking',
    'blocky',
    'blonde',
    'bloody',
    'blue',
    'blushing',
    'boiling',
    'bold',
    'bone',
    'boolean',
    'booming',
    'boorish',
    'bordeaux',
    'bored',
    'boring',
    'bossy',
    'bottom',
    'bouncy',
    'bounded',
    'boundless',
    'boxy',
    'brainy',
    'braised',
    'brash',
    'brass',
    'brave',
    'brawny',
    'breakable',
    'breezy',
    'brief',
    'bright',
    'brilliant',
    'briny',
    'brisk',
    'broad',
    'broken',
    'bronze',
    'brown',
    'brownian',
    'brutal',
    'bruteforce',
    'bumpy',
    'buoyant',
    'burgundy',
    'burly',
    'burning',
    'bursting',
    'bustling',
    'busy',
    'buttery',
    'cagey',
    'calculating',
    'callous',
    'calm',
    'camel',
    'can',
    'canary',
    'candied',
    'canny',
    'capable',
    'capital',
    'capitalist',
    'capricious',
    'caramel',
    'caramelized',
    'cared',
    'careful',
    'careless',
    'caring',
    'casual',
    'causal',
    'cautious',
    'ceaseless',
    'celeste',
    'celestial',
    'central',
    'certain',
    'cerulean',
    'chalky',
    'chamfered',
    'champagne',
    'champion',
    'changeable',
    'changing',
    'chaotic',
    'characteristic',
    'charcoal',
    'charitable',
    'charmed',
    'charming',
    'chartreuse',
    'cheap',
    'cheeky',
    'cheerful',
    'cheesy',
    'chemical',
    'chestnut',
    'chewy',
    'chic',
    'chief',
    'childlike',
    'chill',
    'chilly',
    'chivalrous',
    'chocolate',
    'chocolaty',
    'choice',
    'chosen',
    'christian',
    'chromatic',
    'chronic',
    'chubby',
    'chummy',
    'chunky',
    'circular',
    'citric',
    'citron',
    'civic',
    'civil',
    'civilian',
    'clammy',
    'claret',
    'classic',
    'classical',
    'classy',
    'clean',
    'clear',
    'clever',
    'climbing',
    'clinical',
    'cloistered',
    'close',
    'closed',
    'closing',
    'cloudy',
    'cloying',
    'clumsy',
    'cluttered',
    'coal',
    'coastal',
    'cobalt',
    'coffee',
    'cogent',
    'cognitive',
    'coherent',
    'coincident',
    'cold',
    'collective',
    'collinear',
    'colonial',
    'colorful',
    'colossal',
    'coloured',
    'colourful',
    'combative',
    'combined',
    'comfortable',
    'comic',
    'coming',
    'commercial',
    'common',
    'communal',
    'communist',
    'commutative',
    'compact',
    'comparable',
    'comparative',
    'compassionate',
    'compatible',
    'competent',
    'competitive',
    'complete',
    'complex',
    'complicated',
    'composed',
    'composite',
    'comprehensive',
    'compulsory',
    'concave',
    'concentric',
    'conceptual',
    'concerned',
    'concise',
    'concrete',
    'concurrent',
    'condemned',
    'condescending',
    'confident',
    'confidential',
    'confused',
    'congruent',
    'connected',
    'conscious',
    'conservation',
    'conservative',
    'considerable',
    'consistent',
    'constant',
    'constitutional',
    'contemporary',
    'content',
    'continental',
    'continued',
    'continuing',
    'continuous',
    'controlled',
    'controversial',
    'convenient',
    'conventional',
    'convex',
    'convinced',
    'convincing',
    'convoluted',
    'cooing',
    'cool',
    'cooperative',
    'coordinated',
    'coped',
    'coplanar',
    'coral',
    'corn',
    'corporate',
    'correct',
    'corresponding',
    'cosmic',
    'costly',
    'counting',
    'courageous',
    'courtly',
    'covering',
    'cowardly',
    'cozy',
    'crabby',
    'crack',
    'cranky',
    'craven',
    'crazy',
    'cream',
    'creamy',
    'creative',
    'credible',
    'creepy',
    'criminal',
    'crimson',
    'crispy',
    'critical',
    'crooked',
    'cross',
    'crowded',
    'crucial',
    'crude',
    'cruel',
    'crunchy',
    'cuddly',
    'cultural',
    'cultured',
    'cumbersome',
    'cunning',
    'curious',
    'curly',
    'current',
    'curved',
    'curvy',
    'cute',
    'cyan',
    'cyclic',
    'cynical',
    'daffy',
    'daily',
    'dainty',
    'damaged',
    'damaging',
    'damp',
    'dandy',
    'dangerous',
    'dapper',
    'daring',
    'dark',
    'dashing',
    'dazzling',
    'dead',
    'deadly',
    'deadpan',
    'deaf',
    'deafening',
    'dear',
    'debonair',
    'decent',
    'decidable',
    'deciding',
    'decisive',
    'decorous',
    'deep',
    'deeply',
    'defeated',
    'defective',
    'defensive',
    'defiant',
    'definite',
    'deft',
    'deliberate',
    'delicate',
    'delicious',
    'delighted',
    'delightful',
    'delirious',
    'deluxe',
    'democratic',
    'demonic',
    'denim',
    'dense',
    'dependent',
    'depressed',
    'deranged',
    'descent',
    'descriptive',
    'desert',
    'deserted',
    'desirable',
    'desired',
    'desperate',
    'destined',
    'detailed',
    'determined',
    'deterministic',
    'developed',
    'developing',
    'devilish',
    'devoted',
    'devout',
    'diachronic',
    'diagonal',
    'dichotomic',
    'didactic',
    'different',
    'difficult',
    'digital',
    'diligent',
    'diplomatic',
    'direct',
    'direful',
    'dirty',
    'disabled',
    'disagreeable',
    'disappointed',
    'disastrous',
    'disciplinary',
    'discreet',
    'discrete',
    'disgusted',
    'disgusting',
    'disillusioned',
    'dispensable',
    'distant',
    'distinct',
    'distinctive',
    'distinguished',
    'distracted',
    'distraught',
    'district',
    'disturbed',
    'disturbing',
    'divergent',
    'diverse',
    'divine',
    'dizzy',
    'domestic',
    'dominant',
    'domineering',
    'doted',
    'doting',
    'double',
    'doubtful',
    'doughy',
    'drab',
    'draconian',
    'dramatic',
    'dreadful',
    'dreamy',
    'dreary',
    'driven',
    'driving',
    'drunk',
    'dry',
    'dual',
    'dull',
    'dusty',
    'dutch',
    'dyadic',
    'dying',
    'dynamic',
    'dysfunctional',
    'each',
    'eager',
    'early',
    'earsplitting',
    'earthy',
    'eastern',
    'easy',
    'eatable',
    'ebony',
    'economic',
    'ecru',
    'ecstatic',
    'edible',
    'educated',
    'educational',
    'eerie',
    'effective',
    'efficacious',
    'efficient',
    'eight',
    'elaborate',
    'elastic',
    'elated',
    'elderly',
    'eldest',
    'electoral',
    'electric',
    'electrical',
    'electronic',
    'elegant',
    'elfin',
    'eligible',
    'elite',
    'embarrassed',
    'embarrassing',
    'emerald',
    'emerging',
    'eminent',
    'emotional',
    'empirical',
    'empty',
    'enabled',
    'enchanted',
    'enchanting',
    'encouraging',
    'endless',
    'endothermic',
    'endurable',
    'energetic',
    'energized',
    'engaged',
    'engaging',
    'enhanced',
    'enigmatic',
    'enjoyed',
    'enormous',
    'enough',
    'entertaining',
    'enthusiastic',
    'entire',
    'entitled',
    'envious',
    'environmental',
    'epic',
    'equable',
    'equal',
    'equidistant',
    'equilateral',
    'equipped',
    'equivalent',
    'erect',
    'erratic',
    'espressivo',
    'essential',
    'established',
    'estimated',
    'eternal',
    'ethereal',
    'ethical',
    'ethnic',
    'evanescent',
    'evasive',
    'even',
    'eventual',
    'every',
    'everyday',
    'evident',
    'evil',
    'evolutionary',
    'evolved',
    'evolving',
    'exact',
    'excellent',
    'exceptional',
    'excess',
    'excessive',
    'excited',
    'exciting',
    'exclusive',
    'exhaustive',
    'existing',
    'exothermic',
    'exotic',
    'expected',
    'expensive',
    'experienced',
    'experimental',
    'expert',
    'explicit',
    'exponential',
    'express',
    'extended',
    'extensive',
    'external',
    'extra',
    'extraordinary',
    'extravagant',
    'extremal',
    'extreme',
    'exuberant',
    'exultant',
    'fabulous',
    'factorial',
    'factual',
    'faded',
    'faint',
    'fair',
    'faithful',
    'fallacious',
    'false',
    'famed',
    'familiar',
    'famous',
    'fanatical',
    'fancy',
    'fantastic',
    'fascinated',
    'fascinating',
    'fashionable',
    'fast',
    'fat',
    'fatal',
    'faulty',
    'favourable',
    'favourite',
    'fearful',
    'fearless',
    'feasible',
    'federal',
    'feigned',
    'feldspar',
    'fellow',
    'fermented',
    'ferocious',
    'fertile',
    'fervent',
    'festering',
    'festive',
    'fierce',
    'fiery',
    'figurative',
    'filthy',
    'final',
    'financial',
    'fine',
    'finicky',
    'finite',
    'firm',
    'first',
    'fiscal',
    'fit',
    'fitting',
    'fixed',
    'flagrant',
    'flaky',
    'flashed',
    'flashy',
    'flat',
    'flavorful',
    'flawless',
    'fleet',
    'flexible',
    'flimsy',
    'flippant',
    'flowery',
    'flowing',
    'fluent',
    'fluffy',
    'flush',
    'fluttering',
    'flying',
    'foamy',
    'focused',
    'foggy',
    'following',
    'fond',
    'foolish',
    'foregoing',
    'foreign',
    'forgetful',
    'forgiving',
    'forlorn',
    'formal',
    'formidable',
    'forthcoming',
    'fortunate',
    'forward',
    'fragile',
    'frail',
    'frank',
    'frantic',
    'frayed',
    'free',
    'freezing',
    'frequent',
    'fresh',
    'fretful',
    'fried',
    'friendly',
    'frightened',
    'frightening',
    'frigid',
    'front',
    'frosty',
    'frozen',
    'fuchsia',
    'full',
    'fumbling',
    'fun',
    'functional',
    'fundamental',
    'funky',
    'funny',
    'furious',
    'furry',
    'furtive',
    'fuscia',
    'future',
    'futuristic',
    'fuzzy',
    'gabby',
    'gainful',
    'gamy',
    'gaping',
    'garrulous',
    'gastric',
    'gaudy',
    'general',
    'generative',
    'generous',
    'genetic',
    'genial',
    'genteel',
    'gentle',
    'genuine',
    'geographical',
    'giant',
    'giddy',
    'gifted',
    'gigantic',
    'gilded',
    'given',
    'giving',
    'glad',
    'glamorous',
    'glass',
    'gleaming',
    'glib',
    'glistening',
    'global',
    'gloomy',
    'glorious',
    'glossy',
    'glowing',
    'glum',
    'gnarly',
    'godly',
    'gold',
    'golden',
    'good',
    'goodly',
    'goofy',
    'gorgeous',
    'gothic',
    'gourmet',
    'governing',
    'graceful',
    'gradual',
    'grand',
    'grandiose',
    'grandioso',
    'grateful',
    'grating',
    'gratis',
    'grave',
    'gravitational',
    'gray',
    'greasy',
    'great',
    'greedy',
    'green',
    'grey',
    'grieving',
    'grilled',
    'grim',
    'gritty',
    'grizzled',
    'groovy',
    'gross',
    'grotesque',
    'grouchy',
    'growing',
    'grown',
    'grubby',
    'gruesome',
    'grumpy',
    'guarded',
    'guided',
    'guiding',
    'guiltless',
    'guilty',
    'gullible',
    'gusty',
    'gutsy',
    'guttural',
    'habitual',
    'half',
    'hallowed',
    'haloed',
    'halting',
    'handicapped',
    'handsome',
    'handsomely',
    'handy',
    'hanging',
    'hapless',
    'happy',
    'hard',
    'hardy',
    'harmless',
    'harmonious',
    'harsh',
    'hasty',
    'heady',
    'healthy',
    'heartbreaking',
    'heartless',
    'hearty',
    'heather',
    'heavenly',
    'heavy',
    'hellish',
    'helped',
    'helpful',
    'helping',
    'helpless',
    'heroic',
    'hesitant',
    'hidden',
    'hideous',
    'high',
    'highfalutin',
    'hilarious',
    'hip',
    'hissing',
    'historic',
    'historical',
    'hoary',
    'holistic',
    'hollow',
    'holy',
    'homeless',
    'homely',
    'honest',
    'honorable',
    'hopeful',
    'horizontal',
    'horrible',
    'hospitable',
    'hostile',
    'hot',
    'huge',
    'hulking',
    'human',
    'humane',
    'humble',
    'humdrum',
    'humid',
    'humongous',
    'humorous',
    'hungry',
    'hunky',
    'hurried',
    'hurt',
    'hushed',
    'husky',
    'hypnotic',
    'hysterical',
    'icky',
    'icy',
    'ideal',
    'identical',
    'ideological',
    'ignorant',
    'ill',
    'illegal',
    'illustrious',
    'imaginary',
    'imaginative',
    'immature',
    'immediate',
    'immense',
    'imminent',
    'immortal',
    'immune',
    'impartial',
    'imperfect',
    'imperial',
    'implicit',
    'impolite',
    'important',
    'imported',
    'impossible',
    'impressed',
    'impressive',
    'improved',
    'impulsive',
    'inadequate',
    'inappropriate',
    'incandescent',
    'inclined',
    'included',
    'inclusive',
    'incompetent',
    'inconclusive',
    'increased',
    'increasing',
    'incredible',
    'independent',
    'indigo',
    'indirect',
    'individual',
    'indulgent',
    'industrial',
    'industrious',
    'inevitable',
    'inexpensive',
    'infallible',
    'infamous',
    'infinite',
    'inflammable',
    'influential',
    'informal',
    'informed',
    'inherent',
    'initial',
    'injured',
    'inland',
    'innate',
    'inner',
    'innocent',
    'innovative',
    'inquisitive',
    'insane',
    'inscribed',
    'insidious',
    'inspired',
    'instant',
    'instinctive',
    'institutional',
    'insufficient',
    'insulated',
    'intact',
    'integral',
    'integrated',
    'intellectual',
    'intelligent',
    'intense',
    'intensive',
    'intent',
    'interested',
    'interesting',
    'intergalactic',
    'interim',
    'interior',
    'intermediate',
    'internal',
    'international',
    'intimate',
    'intractable',
    'intricate',
    'inventive',
    'inverse',
    'inverted',
    'investor',
    'invincible',
    'invisible',
    'inviting',
    'involved',
    'irate',
    'iron',
    'irregular',
    'irrelevant',
    'irreverent',
    'irritating',
    'isobaric',
    'isochoric',
    'isolated',
    'isometric',
    'isomorphic',
    'isothermal',
    'itchy',
    'ivory',
    'jaded',
    'jagged',
    'jazzed',
    'jazzy',
    'jealous',
    'jellied',
    'jittery',
    'joint',
    'jolly',
    'jovial',
    'joyful',
    'joyous',
    'jubilant',
    'judicial',
    'judicious',
    'juicy',
    'jumbled',
    'jumbo',
    'jumpy',
    'junior',
    'just',
    'juvenile',
    'kaput',
    'keen',
    'key',
    'khaki',
    'kickass',
    'kind',
    'kindhearted',
    'kindly',
    'kinetic',
    'kingly',
    'knotty',
    'knowing',
    'knowledgeable',
    'known',
    'knurled',
    'labored',
    'labour',
    'lackadaisical',
    'lacking',
    'lame',
    'lamentable',
    'laminated',
    'languid',
    'large',
    'largo',
    'last',
    'lasting',
    'late',
    'latent',
    'latin',
    'laughable',
    'lavish',
    'lawful',
    'lazy',
    'lead',
    'leading',
    'lean',
    'learning',
    'leather',
    'left',
    'legacy',
    'legal',
    'legible',
    'legislative',
    'legit',
    'legitimate',
    'lengthy',
    'lenient',
    'lesser',
    'lethal',
    'level',
    'lewd',
    'lexical',
    'liable',
    'liberal',
    'libretto',
    'light',
    'likeable',
    'liked',
    'likely',
    'limber',
    'lime',
    'limited',
    'limitless',
    'limping',
    'linear',
    'linguistic',
    'liquid',
    'literary',
    'literate',
    'little',
    'live',
    'lively',
    'livid',
    'living',
    'local',
    'logical',
    'lonely',
    'long',
    'longing',
    'loose',
    'lopsided',
    'loquacious',
    'lost',
    'loud',
    'lousy',
    'loutish',
    'loved',
    'lovely',
    'loving',
    'low',
    'lower',
    'lowly',
    'loyal',
    'lucid',
    'lucky',
    'ludicrous',
    'lumpy',
    'lush',
    'luxuriant',
    'lying',
    'lyrical',
    'lytic',
    'macabre',
    'macho',
    'mad',
    'maddening',
    'madly',
    'magenta',
    'magic',
    'magical',
    'magnetic',
    'magnificent',
    'main',
    'majestic',
    'major',
    'makeshift',
    'male',
    'malicious',
    'mammoth',
    'managerial',
    'managing',
    'maniac',
    'maniacal',
    'manual',
    'marginal',
    'marinated',
    'marine',
    'marked',
    'maroon',
    'married',
    'marvellous',
    'marvelous',
    'marxist',
    'mashed',
    'mass',
    'massive',
    'master',
    'matching',
    'material',
    'materialistic',
    'mathematical',
    'matte',
    'mature',
    'max',
    'maxed',
    'maximum',
    'mean',
    'meaningful',
    'measly',
    'measured',
    'meaty',
    'mechanical',
    'median',
    'medical',
    'medieval',
    'medium',
    'meek',
    'meet',
    'mellow',
    'melodic',
    'melted',
    'mental',
    'merciful',
    'merciless',
    'mere',
    'merry',
    'messy',
    'metal',
    'metallic',
    'metropolitan',
    'mid',
    'middle',
    'mighty',
    'mild',
    'military',
    'milky',
    'mindless',
    'miniature',
    'minimal',
    'minimum',
    'ministerial',
    'minor',
    'mint',
    'minty',
    'mirthful',
    'miscreant',
    'miserable',
    'misleading',
    'missing',
    'misty',
    'mixed',
    'moaning',
    'mobile',
    'model',
    'moderate',
    'moderato',
    'modern',
    'modest',
    'moist',
    'moldy',
    'molecular',
    'molten',
    'momentous',
    'monetary',
    'monthly',
    'moonlit',
    'moral',
    'motionless',
    'mountainous',
    'moved',
    'moving',
    'mucho',
    'muddled',
    'muddy',
    'muffled',
    'multiple',
    'mundane',
    'murky',
    'mushy',
    'musical',
    'mute',
    'muted',
    'mutual',
    'mysterious',
    'naive',
    'naked',
    'nappy',
    'narrow',
    'nasty',
    'national',
    'native',
    'natural',
    'naughty',
    'nauseating',
    'nauseous',
    'naval',
    'navy',
    'near',
    'nearby',
    'nearest',
    'neat',
    'nebulous',
    'necessary',
    'needed',
    'needless',
    'needy',
    'negative',
    'neighborly',
    'neighbouring',
    'nervous',
    'neutral',
    'new',
    'next',
    'nice',
    'nifty',
    'nimble',
    'nippy',
    'noble',
    'noiseless',
    'noisy',
    'nonchalant',
    'nondescript',
    'nondeterministic',
    'nonstop',
    'normal',
    'northern',
    'nostalgic',
    'nosy',
    'notable',
    'noted',
    'novel',
    'noxious',
    'nuclear',
    'null',
    'nullary',
    'numberless',
    'numero',
    'numerous',
    'nursing',
    'nutritious',
    'nutty',
    'oafish',
    'obedient',
    'obeisant',
    'objective',
    'obliged',
    'obliging',
    'oblique',
    'obnoxious',
    'obscene',
    'obsequious',
    'observant',
    'obsolete',
    'obtainable',
    'obtuse',
    'obvious',
    'occasional',
    'occupational',
    'oceanic',
    'odd',
    'odious',
    'offbeat',
    'official',
    'offline',
    'oily',
    'okay',
    'old',
    'olive',
    'olympic',
    'omniscient',
    'one',
    'onerous',
    'online',
    'only',
    'open',
    'operational',
    'opposite',
    'optical',
    'optimal',
    'optimistic',
    'optimum',
    'oral',
    'orange',
    'ordered',
    'ordinary',
    'organic',
    'organisational',
    'oriented',
    'original',
    'ornery',
    'orthodox',
    'orthogonal',
    'oscillating',
    'ossified',
    'other',
    'outdoor',
    'outer',
    'outgoing',
    'outrageous',
    'outside',
    'outstanding',
    'oval',
    'overall',
    'overcast',
    'overconfident',
    'overjoyed',
    'overrated',
    'overseas',
    'overt',
    'overwhelming',
    'overwrought',
    'pacific',
    'painful',
    'painstaking',
    'pale',
    'pallid',
    'paltry',
    'panicky',
    'panoramic',
    'paper',
    'parallel',
    'parched',
    'parental',
    'parliamentary',
    'parsimonious',
    'partial',
    'particular',
    'passing',
    'passive',
    'past',
    'pastoral',
    'pathetic',
    'patient',
    'payable',
    'peaceful',
    'peachy',
    'peculiar',
    'pedantic',
    'penitent',
    'pensive',
    'peppy',
    'perfect',
    'periodic',
    'permanent',
    'permissible',
    'perpendicular',
    'perpetual',
    'persistent',
    'personal',
    'petite',
    'philosophical',
    'phobic',
    'physical',
    'picayune',
    'picked',
    'piercing',
    'pink',
    'piquant',
    'pithy',
    'placid',
    'plain',
    'planar',
    'planned',
    'plant',
    'plastic',
    'plausible',
    'pleasant',
    'pleased',
    'pleasing',
    'plucky',
    'plum',
    'plumb',
    'poached',
    'poetic',
    'pointed',
    'pointless',
    'poised',
    'poky',
    'polished',
    'polite',
    'political',
    'polynomial',
    'poor',
    'popular',
    'posh',
    'positive',
    'possessive',
    'possible',
    'potent',
    'potential',
    'pounded',
    'powerful',
    'practical',
    'precious',
    'precise',
    'preferred',
    'pregnant',
    'preliminary',
    'premier',
    'premium',
    'prepared',
    'present',
    'presidential',
    'presto',
    'pretty',
    'previous',
    'pricey',
    'prickly',
    'primary',
    'prime',
    'primitive',
    'primo',
    'primordial',
    'principal',
    'printed',
    'prior',
    'private',
    'prized',
    'pro',
    'probable',
    'product',
    'productive',
    'professional',
    'profitable',
    'profound',
    'profuse',
    'progressive',
    'prominent',
    'promising',
    'promoted',
    'prompt',
    'proper',
    'proposed',
    'prospective',
    'protective',
    'protestant',
    'proud',
    'proven',
    'provincial',
    'psychedelic',
    'psychiatric',
    'psychological',
    'psychotic',
    'public',
    'puffy',
    'pumped',
    'punchy',
    'puny',
    'pure',
    'pureed',
    'purple',
    'purring',
    'pushy',
    'puzzled',
    'puzzling',
    'quack',
    'quadratic',
    'quaint',
    'qualified',
    'quality',
    'quantum',
    'quarrelsome',
    'querulous',
    'questionable',
    'quick',
    'quickest',
    'quiet',
    'quintessential',
    'quirky',
    'quixotic',
    'quizzical',
    'rabid',
    'racial',
    'rad',
    'radial',
    'radiant',
    'radical',
    'radioactive',
    'ragged',
    'rainy',
    'rambunctious',
    'rampant',
    'rancid',
    'random',
    'randomized',
    'rank',
    'rapid',
    'rare',
    'raspy',
    'rational',
    'ratty',
    'raw',
    'reach',
    'ready',
    'real',
    'realistic',
    'rear',
    'reasonable',
    'rebel',
    'recent',
    'receptive',
    'recondite',
    'rectilinear',
    'recursive',
    'red',
    'reduced',
    'redundant',
    'refined',
    'reflective',
    'regal',
    'regional',
    'registered',
    'regular',
    'regulatory',
    'related',
    'relative',
    'relaxed',
    'relaxing',
    'relevant',
    'reliable',
    'relieved',
    'religious',
    'reluctant',
    'remaining',
    'remarkable',
    'reminiscent',
    'remote',
    'renewed',
    'renewing',
    'representative',
    'repulsive',
    'required',
    'resident',
    'residential',
    'resilient',
    'resolute',
    'resolved',
    'resolving',
    'resonant',
    'respectable',
    'respectful',
    'respective',
    'responsible',
    'rested',
    'resultant',
    'resulting',
    'retail',
    'retired',
    'reverent',
    'revolutionary',
    'rhetorical',
    'rich',
    'ridiculous',
    'right',
    'righteous',
    'rightful',
    'rigid',
    'ripe',
    'rising',
    'ritzy',
    'rival',
    'roaring',
    'roasted',
    'robust',
    'rolling',
    'romantic',
    'roomy',
    'rooted',
    'rosy',
    'rotten',
    'rough',
    'round',
    'rounded',
    'rowdy',
    'royal',
    'rubber',
    'rubbery',
    'ruddy',
    'rude',
    'rugged',
    'ruling',
    'running',
    'rural',
    'rust',
    'rustic',
    'ruthless',
    'sable',
    'sacred',
    'sad',
    'safe',
    'salmon',
    'salty',
    'same',
    'sassy',
    'satisfactory',
    'satisfied',
    'satisfying',
    'saucy',
    'savage',
    'saved',
    'saving',
    'savory',
    'savvy',
    'scalding',
    'scandalous',
    'scarce',
    'scared',
    'scary',
    'scattered',
    'scenic',
    'scientific',
    'scintillating',
    'scornful',
    'scrawny',
    'screeching',
    'scruffy',
    'searing',
    'seasoned',
    'second',
    'secondary',
    'secret',
    'secretive',
    'secure',
    'sedate',
    'seemly',
    'seething',
    'select',
    'selected',
    'selective',
    'selfish',
    'semantic',
    'senile',
    'senior',
    'sensible',
    'sensitive',
    'separate',
    'serene',
    'serious',
    'settled',
    'settling',
    'several',
    'severe',
    'sexual',
    'shabby',
    'shaggy',
    'shaky',
    'shallow',
    'shared',
    'sharing',
    'sharp',
    'sheer',
    'shining',
    'shiny',
    'shivering',
    'shocked',
    'shocking',
    'short',
    'shortest',
    'showy',
    'shrewd',
    'shrill',
    'shrivelled',
    'shut',
    'shy',
    'sick',
    'sienna',
    'significant',
    'silent',
    'silky',
    'silly',
    'silver',
    'similar',
    'simmered',
    'simple',
    'simplistic',
    'sincere',
    'single',
    'singular',
    'sizzling',
    'skilled',
    'skillful',
    'skinny',
    'sleek',
    'sleepy',
    'slick',
    'slight',
    'slim',
    'slimy',
    'slippery',
    'sloppy',
    'slow',
    'sluggish',
    'small',
    'smart',
    'smashing',
    'smelly',
    'smiley',
    'smiling',
    'smoggy',
    'smoked',
    'smoky',
    'smooth',
    'snappy',
    'snazzy',
    'sneaky',
    'snobbish',
    'snotty',
    'snowy',
    'snugly',
    'social',
    'socialist',
    'soft',
    'soggy',
    'solar',
    'sole',
    'solid',
    'solitary',
    'soluble',
    'somber',
    'some',
    'sophisticated',
    'sordid',
    'sore',
    'sorry',
    'sought',
    'sound',
    'sour',
    'southern',
    'soviet',
    'spacial',
    'spare',
    'sparkling',
    'sparse',
    'spatial',
    'special',
    'specific',
    'specified',
    'spectacular',
    'speedy',
    'spicy',
    'spiffy',
    'spiky',
    'spiritual',
    'spiteful',
    'splendid',
    'spontaneous',
    'spooky',
    'sporting',
    'spotless',
    'spotted',
    'spotty',
    'spry',
    'spurious',
    'squalid',
    'square',
    'squealing',
    'squeamish',
    'stable',
    'staccato',
    'staff',
    'staking',
    'stale',
    'standard',
    'standing',
    'star',
    'stark',
    'static',
    'statistical',
    'statuesque',
    'statutory',
    'steadfast',
    'steady',
    'steamed',
    'steel',
    'steep',
    'stereotyped',
    'sterling',
    'stern',
    'sticky',
    'stiff',
    'still',
    'stimulating',
    'stingy',
    'stirred',
    'stirring',
    'stoic',
    'stone',
    'stormy',
    'straight',
    'straightforward',
    'strange',
    'strategic',
    'strict',
    'striking',
    'stringy',
    'striped',
    'strong',
    'structural',
    'stubborn',
    'stuck',
    'stunning',
    'stupefied',
    'stupendous',
    'stupid',
    'sturdy',
    'suave',
    'subdued',
    'subjective',
    'subsequent',
    'substantial',
    'subtle',
    'successful',
    'successive',
    'succinct',
    'succulent',
    'sudden',
    'sufficient',
    'sugary',
    'suitable',
    'suited',
    'sulky',
    'summary',
    'sunny',
    'sunset',
    'super',
    'superb',
    'superficial',
    'superior',
    'supporting',
    'supposed',
    'supreme',
    'sure',
    'surprised',
    'surprising',
    'surrounding',
    'surviving',
    'suspicious',
    'swank',
    'swanky',
    'swarm',
    'sweeping',
    'sweet',
    'swell',
    'sweltering',
    'swift',
    'symbolic',
    'symmetric',
    'sympathetic',
    'symptomatic',
    'synchronic',
    'synonymous',
    'syrupy',
    'systematic',
    'taboo',
    'tacit',
    'tacky',
    'talented',
    'tall',
    'tame',
    'tan',
    'tangible',
    'tangy',
    'tart',
    'tasteful',
    'tasteless',
    'tasty',
    'tattered',
    'tawdry',
    'taxonomic',
    'teaching',
    'teal',
    'tearful',
    'technical',
    'technological',
    'tedious',
    'teenage',
    'teeny',
    'telling',
    'temperate',
    'tempered',
    'temporary',
    'tender',
    'tense',
    'tenuous',
    'terminal',
    'ternary',
    'terrible',
    'terrific',
    'territorial',
    'tested',
    'testy',
    'thankful',
    'then',
    'theoretical',
    'therapeutic',
    'thick',
    'thin',
    'thinkable',
    'third',
    'thirsty',
    'thorough',
    'thoughtful',
    'thoughtless',
    'threadbare',
    'threaded',
    'threatening',
    'thriving',
    'thundering',
    'tidy',
    'tight',
    'timely',
    'timid',
    'tiny',
    'tired',
    'tiresome',
    'toasted',
    'together',
    'tolerant',
    'tomato',
    'toothsome',
    'top',
    'topical',
    'topped',
    'tops',
    'torpid',
    'tory',
    'tossed',
    'total',
    'touched',
    'touching',
    'tough',
    'touted',
    'towering',
    'toxic',
    'tractable',
    'traditional',
    'tragic',
    'tranquil',
    'trashy',
    'tremendous',
    'tricky',
    'trim',
    'trite',
    'tropical',
    'troubled',
    'truculent',
    'true',
    'trusted',
    'trusting',
    'trusty',
    'truthful',
    'try',
    'typical',
    'ubiquitous',
    'ugliest',
    'ugly',
    'ultimate',
    'ultra',
    'unable',
    'unacceptable',
    'unaccountable',
    'unadvised',
    'unarmed',
    'unary',
    'unaware',
    'unbecoming',
    'unbiased',
    'uncertain',
    'unchanged',
    'uncomfortable',
    'uncommon',
    'unconscious',
    'uncovered',
    'undecidable',
    'underground',
    'underlying',
    'understood',
    'undirected',
    'undisturbed',
    'unemployed',
    'unequal',
    'unequaled',
    'uneven',
    'unexpected',
    'unfair',
    'unfortunate',
    'unhappy',
    'unhealthy',
    'unified',
    'uniform',
    'unintelligent',
    'uninterested',
    'unique',
    'united',
    'universal',
    'unkempt',
    'unknown',
    'unlikely',
    'unnatural',
    'unnecessary',
    'unpleasant',
    'unproductive',
    'unruly',
    'unsightly',
    'unsolvable',
    'unsorted',
    'unsuitable',
    'untidy',
    'unused',
    'unusual',
    'unwavering',
    'unwieldy',
    'unwilling',
    'unwritten',
    'upbeat',
    'uplifting',
    'upper',
    'uppity',
    'upright',
    'upset',
    'uptight',
    'upward',
    'urban',
    'urbane',
    'urgent',
    'usable',
    'used',
    'useful',
    'useless',
    'usual',
    'utmost',
    'utopian',
    'utter',
    'uttermost',
    'vacuous',
    'vagabond',
    'vague',
    'vain',
    'valid',
    'valuable',
    'valued',
    'variable',
    'varied',
    'various',
    'varying',
    'vast',
    'vengeful',
    'venomous',
    'verbal',
    'verdant',
    'verified',
    'versed',
    'vertical',
    'very',
    'vestal',
    'viable',
    'vibrant',
    'vibrato',
    'vicarious',
    'vicious',
    'victorious',
    'vigorous',
    'vintage',
    'violent',
    'violet',
    'virulent',
    'visible',
    'visiting',
    'visual',
    'vital',
    'vitreous',
    'vivacious',
    'vivid',
    'vocal',
    'vocational',
    'vogue',
    'voiceless',
    'volatile',
    'volumetric',
    'voluminous',
    'voluntary',
    'voracious',
    'vulnerable',
    'wacky',
    'waggish',
    'waiting',
    'wakeful',
    'wandering',
    'wanted',
    'wanting',
    'warlike',
    'warm',
    'warped',
    'wary',
    'wasteful',
    'watery',
    'weak',
    'wealthy',
    'weary',
    'weathered',
    'wee',
    'weekly',
    'weighted',
    'weird',
    'welcome',
    'welcomed',
    'well',
    'western',
    'wet',
    'whimsical',
    'whispering',
    'white',
    'whole',
    'wholesale',
    'wicked',
    'wicker',
    'wide',
    'widespread',
    'wiggly',
    'wild',
    'wilful',
    'willing',
    'willowy',
    'wily',
    'windy',
    'winged',
    'winning',
    'wintry',
    'wired',
    'wiry',
    'wise',
    'wispy',
    'wistful',
    'wittering',
    'witty',
    'woebegone',
    'wonderful',
    'wondrous',
    'wood',
    'wooden',
    'woolen',
    'woozy',
    'workable',
    'working',
    'worldwide',
    'worn',
    'worried',
    'worrying',
    'worthwhile',
    'worthy',
    'wrathful',
    'wretched',
    'written',
    'wrong',
    'wry',
    'xenacious',
    'xenial',
    'xenogeneic',
    'xenophobic',
    'xeric',
    'xerothermic',
    'yabbering',
    'yammering',
    'yappiest',
    'yappy',
    'yawning',
    'yearling',
    'yearning',
    'yeasty',
    'yelling',
    'yellow',
    'yelping',
    'yielding',
    'yodelling',
    'young',
    'youngest',
    'youthful',
    'ytterbic',
    'yucky',
    'yummy',
    'zany',
    'zealous',
    'zenzeroth',
    'zestful',
    'zesty',
    'zingy',
    'zippy',
    'zonal',
    'zonked',
    'zoophagous',
    'zygomorphic',
    'zygotic',

]
