SPORTS = [
    'archer',
    'arena',
    'arrow',
    'athlete',
    'axel',
    'badminton',
    'ball',
    'base',
    'batter',
    'bicycle',
    'bike',
    'bocce',
    'bow',
    'box',
    'canoe',
    'catch',
    'cleats',
    'club',
    'coach',
    'compete',
    'crew',
    'cricket',
    'cycle',
    'cyclist',
    'dart',
    'defense',
    'diamond',
    'dive',
    'diver',
    'exercise',
    'fencing',
    'field',
    'fitness',
    'frisbee',
    'game',
    'gear',
    'goal',
    'goalie',
    'golf',
    'golfer',
    'guard',
    'gym',
    'gymnast',
    'helmet',
    'hockey',
    'home',
    'hoop',
    'hoops',
    'infield',
    'inning',
    'javelin',
    'jog',
    'judo',
    'jump',
    'jumper',
    'karate',
    'kayak',
    'kites',
    'lacrosse',
    'league',
    'lose',
    'loser',
    'luge',
    'major',
    'mallet',
    'mat',
    'medal',
    'mitt',
    'move',
    'net',
    'offense',
    'olympics',
    'out',
    'paddle',
    'play',
    'player',
    'polo',
    'pool',
    'puck',
    'quarter',
    'quiver',
    'race',
    'racer',
    'referee',
    'relay',
    'ride',
    'rink',
    'row',
    'rower',
    'sail',
    'score',
    'scuba',
    'skate',
    'ski',
    'skier',
    'slalom',
    'sled',
    'sledder',
    'snowboard',
    'soccer',
    'sport',
    'squash',
    'stadium',
    'stick',
    'surfer',
    'swim',
    'swimmer',
    'tag',
    'target',
    'team',
    'tee',
    'tennis',
    'throw',
    'tie',
    'triathlon',
    'umpire',
    'volley',
    'walk',
    'weights',
    'win',
    'winner',
    'winning',
    'wrestler',

]
