COMPUTER_SCIENCE = [
    'action',
    'ai',
    'alert',
    'algorithm',
    'alias',
    'allen',
    'alphabet',
    'antivirus',
    'app',
    'application',
    'argument',
    'array',
    'ascii',
    'assembly',
    'automaton',
    'backend',
    'bandwidth',
    'bash',
    'bin',
    'bintree',
    'bit',
    'block',
    'bluetooth',
    'boo',
    'boolean',
    'boot',
    'branch',
    'broadcast',
    'browser',
    'buffer',
    'bug',
    'build',
    'bus',
    'button',
    'byte',
    'c++',
    'cache',
    'capacity',
    'captcha',
    'character',
    'chip',
    'class',
    'click',
    'cluster',
    'code',
    'codeline',
    'command',
    'comment',
    'commit',
    'compiler',
    'compression',
    'computer',
    'configuration',
    'constants',
    'container',
    'cookies',
    'cores',
    'cpu',
    'cut',
    'daemon',
    'data',
    'database',
    'datatable',
    'debug',
    'declaration',
    'desktop',
    'developer',
    'device',
    'dictionary',
    'directory',
    'disk',
    'dns',
    'docker',
    'documents',
    'domains',
    'download',
    'drivers',
    'dsl',
    'email',
    'emulator',
    'encryption',
    'error',
    'ethernet',
    'event',
    'exception',
    'executable',
    'expression',
    'extension',
    'factor',
    'factorial',
    'file',
    'filter',
    'firewall',
    'float',
    'flow',
    'foo',
    'forloop',
    'fractals',
    'frame',
    'ftp',
    'functions',
    'gateway',
    'gif',
    'gigabyte',
    'github',
    'google',
    'gpu',
    'graphics',
    'hacker',
    'hardcode',
    'hardware',
    'hash',
    'heap',
    'hex',
    'host',
    'html',
    'http',
    'hyperlink',
    'icloud',
    'icon',
    'ide',
    'ifstatement',
    'image',
    'imap',
    'inline',
    'input',
    'instruction',
    'integer',
    'interface',
    'internet',
    'interpreter',
    'intranet',
    'ip',
    'iteration',
    'java',
    'javascript',
    'jpeg',
    'kernel',
    'keyword',
    'kilobyte',
    'lan',
    'language',
    'laptop',
    'link',
    'linux',
    'list',
    'literal',
    'load',
    'log',
    'login',
    'loop',
    'machine',
    'malware',
    'megabyte',
    'memory',
    'method',
    'microsoft',
    'mode',
    'module',
    'monitor',
    'motherboard',
    'multimedia',
    'negation',
    'network',
    'notebook',
    'null',
    'object',
    'operand',
    'operator',
    'output',
    'overflow',
    'package',
    'packet',
    'parameter',
    'parser',
    'passkey',
    'password',
    'patch',
    'path',
    'pattern',
    'performance',
    'petabyte',
    'phishing',
    'pixel',
    'pointer',
    'port',
    'prefix',
    'procedure',
    'process',
    'processor',
    'profile',
    'program',
    'programmer',
    'programming',
    'property',
    'protocol',
    'proxy',
    'python',
    'query',
    'queue',
    'ram',
    'reboot',
    'record',
    'recurrence',
    'recursion',
    'reduction',
    'relation',
    'reload',
    'reset',
    'rgb',
    'root',
    'router',
    'routine',
    'runtime',
    'scope',
    'screenshot',
    'script',
    'search',
    'segment',
    'sequence',
    'server',
    'set',
    'shebang',
    'shell',
    'simulation',
    'snippet',
    'software',
    'sort',
    'sourcecode',
    'spam',
    'stack',
    'stackoverflow',
    'storage',
    'strings',
    'stroustrup',
    'subroutine',
    'suffix',
    'supercomputer',
    'syntax',
    'system',
    'tail',
    'terabyte',
    'terminal',
    'text',
    'threads',
    'token',
    'toolbar',
    'torvalds',
    'torwalds',
    'touch',
    'transfer',
    'trojan',
    'truetype',
    'turing',
    'type',
    'unicode',
    'union',
    'unix',
    'upload',
    'uptime',
    'url',
    'usb',
    'user',
    'username',
    'utility',
    'variables',
    'view',
    'virus',
    'wan',
    'wifi',
    'windows',
    'workstation',
    'wozniak',
    'www',
    'xml',
    'yaml',
    'zip',

]
