ARCHITECTURE = [
    'abacus',
    'accolade',
    'apron',
    'arcade',
    'arch',
    'architect',
    'archway',
    'arris',
    'atrium',
    'balcony',
    'baluster',
    'balustrade',
    'bargeboard',
    'basilica',
    'belvedere',
    'blobitecture',
    'blueprint',
    'bonneted',
    'bossage',
    'brace',
    'bracket',
    'bulwark',
    'burjalarab',
    'cancellus',
    'cant',
    'casement',
    'cathedral',
    'chimney',
    'cinquecento',
    'circulation',
    'colonnade',
    'column',
    'construction',
    'corbel',
    'cornice',
    'courtyard',
    'cresting',
    'crypt',
    'cryptoporticus',
    'cupola',
    'deconstruction',
    'dentil',
    'dentils',
    'design',
    'dimensions',
    'dome',
    'dormer',
    'eiffletower',
    'elevations',
    'engawa',
    'entablature',
    'ergonomy',
    'exterior',
    'facade',
    'fanlights',
    'fenestration',
    'finial',
    'floor',
    'foil',
    'foundation',
    'frieze',
    'gable',
    'gallerie',
    'gargoyle',
    'gazebo',
    'infrastructure',
    'intercolumniation',
    'interior',
    'jettying',
    'keystone',
    'landscaping',
    'loculus',
    'loggia',
    'lunette',
    'mascaron',
    'masonry',
    'minaret',
    'molding',
    'mortise',
    'mullion',
    'muntin',
    'nave',
    'oculus',
    'palladian',
    'panel',
    'parapet',
    'patio',
    'pavilion',
    'pediment',
    'pelmet',
    'pergola',
    'phiale',
    'pier',
    'pilaster',
    'plaza',
    'plinth',
    'portcullis',
    'portico',
    'projections',
    'quoin',
    'raincap',
    'roof',
    'rotunda',
    'roundel',
    'saltbox',
    'sash',
    'setback',
    'sidelight',
    'skyscraper',
    'soffit',
    'spandrel',
    'spire',
    'stoop',
    'structure',
    'symmetries',
    'tajmahal',
    'tenon',
    'terrace',
    'tower',
    'tracery',
    'transom',
    'triglyph',
    'truss',
    'turret',
    'tympanum',
    'undercroft',
    'urbanism',
    'vault',
    'veranda',
    'void',

]
