BIOLOGY = [
    'abdomen',
    'abiogenesis',
    'absorption',
    'adaptation',
    'adhesion',
    'agonist',
    'aldosterone',
    'algae',
    'allantois',
    'ammonification',
    'amnion',
    'amniotes',
    'amoeba',
    'anabolism',
    'anaphase',
    'anaplasia',
    'anatomy',
    'angiosperm',
    'animal',
    'antenna',
    'anthropometry',
    'antibiotic',
    'antioxidant',
    'aorta',
    'apoplexy',
    'apoptosis',
    'appendage',
    'arthropod',
    'astrobiology',
    'atavism',
    'atrophy',
    'autoimmunity',
    'autophagy',
    'autopsy',
    'autosomes',
    'autotroph',
    'auxin',
    'axon',
    'benthos',
    'bilirubin',
    'biogeography',
    'biologist',
    'biomass',
    'biome',
    'biomechanics',
    'biomimicry',
    'biophysics',
    'biopsy',
    'biosensor',
    'bipedalism',
    'bivalve',
    'blastocyst',
    'blood',
    'botany',
    'bovine',
    'brain',
    'bronchioles',
    'bryophyte',
    'calmodulin',
    'carcinoma',
    'carotenoids',
    'carrion',
    'cartilage',
    'catabolism',
    'centromere',
    'ceruloplasmin',
    'chemiosmosis',
    'chemoautotroph',
    'chemoheterotroph',
    'chemokines',
    'chemosynthesis',
    'chitin',
    'chlorophyll',
    'chloroplast',
    'chlorosis',
    'chordate',
    'chorion',
    'chyme',
    'cilium',
    'clade',
    'cladistics',
    'cladogram',
    'cloaca',
    'cloning',
    'codominance',
    'coelom',
    'coevolution',
    'cofactor',
    'colony',
    'commensalism',
    'community',
    'competition',
    'consumer',
    'copepod',
    'crenation',
    'cristae',
    'cryobiology',
    'crystallization',
    'cultivar',
    'curare',
    'cytokinesis',
    'cytolysis',
    'cytoplasm',
    'cytoskeleton',
    'cytosol',
    'darwin',
    'denature',
    'dendrite',
    'desmosomes',
    'detritivore',
    'deuterostome',
    'diastole',
    'diatom',
    'dicot',
    'disaccharide',
    'dobzhansky',
    'domain',
    'ear',
    'ecdysis',
    'echinoderm',
    'ecology',
    'ecosystem',
    'ecotype',
    'ectoderm',
    'ectotherm',
    'egg',
    'embryo',
    'embryology',
    'emulsify',
    'endemism',
    'endoderm',
    'endoskeleton',
    'endosperm',
    'endothelium',
    'epidemiology',
    'epiphyte',
    'epistasis',
    'esophagus',
    'estrogen',
    'ethology',
    'eubacteria',
    'eukaryote',
    'euphoria',
    'euthymic',
    'evolution',
    'excretion',
    'exocytosis',
    'exoskeleton',
    'extinction',
    'extirpation',
    'extremophile',
    'eyes',
    'fat',
    'fauna',
    'fecundity',
    'fertilization',
    'fetus',
    'filtration',
    'flagella',
    'flower',
    'fluoride',
    'foot',
    'forest',
    'formaldehyde',
    'fossils',
    'frenulum',
    'fungi',
    'gamete',
    'gametophyte',
    'gastrulation',
    'genetics',
    'genotype',
    'genus',
    'geriatrics',
    'germination',
    'gerontology',
    'gibberellin',
    'gland',
    'gluconeogenesis',
    'glycerol',
    'glycogen',
    'glycogenesis',
    'glycogenolysis',
    'gonad',
    'gradualism',
    'gravitropism',
    'gymnosperm',
    'head',
    'heart',
    'hematopoiesis',
    'heme',
    'herbaceous',
    'heredity',
    'hermaphrodite',
    'herpetology',
    'heterotroph',
    'heterozygous',
    'hibernation',
    'histology',
    'homeostasis',
    'homolog',
    'homoplasy',
    'hormone',
    'horticulture',
    'hydrolyze',
    'hyperosmotic',
    'hyperplasia',
    'imago',
    'interphase',
    'invertebrate',
    'irradiation',
    'kingdom',
    'labia',
    'lactase',
    'larva',
    'leaf',
    'legume',
    'lesion',
    'leukocyte',
    'ligand',
    'linneus',
    'lipolysis',
    'liposome',
    'liver',
    'liverworts',
    'lymph',
    'lyse',
    'lysosome',
    'maceration',
    'macroevolution',
    'macromolecule',
    'macrophage',
    'mastication',
    'meiosis',
    'mendel',
    'meristem',
    'mesentery',
    'mesoderm',
    'metamerism',
    'metamorphosis',
    'metaphase',
    'metastasize',
    'methanol',
    'microevolution',
    'microfilament',
    'microorganisms',
    'microscope',
    'microtubule',
    'miosis',
    'mitochondria',
    'mitochondrion',
    'mitosis',
    'molecules',
    'monera',
    'monocot',
    'monomer',
    'monosomy',
    'morphology',
    'mosses',
    'motility',
    'mucus',
    'multicellular',
    'muscle',
    'mutualism',
    'mycology',
    'mycorrhizae',
    'myofibril',
    'nephrology',
    'nephron',
    'neurogenesis',
    'neuron',
    'neuroscience',
    'niche',
    'nucleoid',
    'omnivore',
    'oncology',
    'organ',
    'organelle',
    'organism',
    'ornithology',
    'ovary',
    'overpopulation',
    'ovule',
    'paleontology',
    'parasite',
    'parasitism',
    'parasitology',
    'parenchyma',
    'paroxysm',
    'pathobiology',
    'pathology',
    'pedigree',
    'peroxisome',
    'perspiration',
    'petiole',
    'phagocytosis',
    'phalanx',
    'pharmacology',
    'pharynx',
    'phenotype',
    'phloem',
    'phospholipid',
    'photoautotroph',
    'photosynthesis',
    'phototropism',
    'phylogeny',
    'phylum',
    'physiology',
    'phytoplankton',
    'pinocytosis',
    'placenta',
    'plant',
    'plasmolysis',
    'pollen',
    'polyp',
    'populations',
    'pore',
    'porphyrin',
    'predation',
    'predator',
    'prey',
    'primates',
    'progesterone',
    'prokaryote',
    'prometaphase',
    'prophase',
    'prosthesis',
    'proteolysis',
    'protists',
    'protoplasm',
    'protostome',
    'protozoa',
    'pseudopod',
    'pyruvate',
    'raptor',
    'reptile',
    'rhizome',
    'roots',
    'saprophyte',
    'sarcolemma',
    'sarcomere',
    'schwann',
    'seashell',
    'secretion',
    'seed',
    'skeleton',
    'skin',
    'speciation',
    'species',
    'sperm',
    'spirochete',
    'spleen',
    'sporangium',
    'spore',
    'sporophyte',
    'stamen',
    'stem',
    'steroid',
    'stoma',
    'stomach',
    'stroma',
    'substrate',
    'sucrose',
    'symbiont',
    'symbiosis',
    'synapomorphy',
    'synapsis',
    'systole',
    'taxon',
    'taxonomy',
    'teeth',
    'telophase',
    'testosterone',
    'thigmotropism',
    'thorax',
    'tissue',
    'tonicity',
    'toxicity',
    'toxicology',
    'toxin',
    'trait',
    'transferrin',
    'transpiration',
    'tropism',
    'turgid',
    'unicellular',
    'urethra',
    'urine',
    'uterus',
    'vacuole',
    'vasodilation',
    'vertebrate',
    'vesicle',
    'viviparous',
    'vivisection',
    'xylem',
    'zonation',
    'zoology',
    'zooplankton',
    'zygospore',
    'zygote',

]
