SCIENTISTS = [
    'agnesi',
    'albattani',
    'allen',
    'almeida',
    'ampere',
    'archimedes',
    'ardinghelli',
    'aryabhata',
    'austin',
    'avogadro',
    'babbage',
    'banach',
    'bernard',
    'bernerslee',
    'bernoulli',
    'bohr',
    'boltzmann',
    'brahmagupta',
    'brenner',
    'cauchy',
    'celsius',
    'copernicus',
    'coulomb',
    'crick',
    'curie',
    'darwin',
    'davinci',
    'dobshansky',
    'dobzhansky',
    'edison',
    'ehrlich',
    'einstein',
    'euclid',
    'euler',
    'faraday',
    'fermi',
    'feynman',
    'fibonacci',
    'fischer',
    'fleming',
    'franklin',
    'fransworth',
    'freud',
    'galileo',
    'galvani',
    'goddard',
    'goldwasser',
    'gutenberg',
    'hawking',
    'heisenberg',
    'helmholtz',
    'hubble',
    'irving',
    'kelvin',
    'kepler',
    'kimura',
    'koch',
    'kolmogorov',
    'kraepelin',
    'lamarck',
    'laplace',
    'lederberg',
    'leeuwenhoek',
    'linnaeus',
    'lorentz',
    'mandelbrot',
    'marconi',
    'maxwell',
    'mcclintock',
    'mendel',
    'mendeleev',
    'morse',
    'neumann',
    'newton',
    'nobel',
    'oppenheimer',
    'pascal',
    'pasteur',
    'pauling',
    'pavlov',
    'planck',
    'pythagoras',
    'ramanujan',
    'raoult',
    'riemann',
    'roentgen',
    'rutherford',
    'schrodinger',
    'shannon',
    'tesla',
    'torvalds',
    'turing',
    'venter',
    'volta',
    'watson',
    'watt',
    'wegener',
    'wilson',
    'wozniak',
    'yamanaka',
    'youyou',

]
