MATH = [
    'abscissa',
    'adjugate',
    'algebra',
    'angle',
    'apex',
    'archimedes',
    'ardinghelli',
    'area',
    'arithmetic',
    'aryabhata',
    'axis',
    'banach',
    'basis',
    'bernoulli',
    'bisector',
    'calculus',
    'cauchy',
    'center',
    'centroid',
    'cevian',
    'circle',
    'combination',
    'cone',
    'congruence',
    'consimilarity',
    'coordinate',
    'cosine',
    'couple',
    'cube',
    'curve',
    'cylinder',
    'degree',
    'denominator',
    'derivative',
    'determinant',
    'diagonal',
    'diameter',
    'differential',
    'dimension',
    'discriminant',
    'dodecagon',
    'edge',
    'envelope',
    'equation',
    'euclid',
    'euler',
    'exponent',
    'fibonacci',
    'flag',
    'focus',
    'formula',
    'fractal',
    'fraction',
    'function',
    'gauss',
    'geometry',
    'graph',
    'grid',
    'height',
    'hexagon',
    'hypotenuse',
    'identity',
    'incircle',
    'independence',
    'integral',
    'intersection',
    'inverse',
    'inversion',
    'involute',
    'kolmogorov',
    'laplace',
    'legs',
    'line',
    'locus',
    'logarithm',
    'mandelbrot',
    'manifold',
    'mapping',
    'matrix',
    'mean',
    'median',
    'midpoint',
    'minute',
    'model',
    'monoid',
    'multiplication',
    'neumann',
    'node',
    'norm',
    'normal',
    'number',
    'numbertheory',
    'octagon',
    'pentagon',
    'perimeter',
    'plane',
    'point',
    'poisson',
    'polygon',
    'polynomial',
    'prime',
    'probability',
    'projection',
    'proof',
    'pyramid',
    'pythagoras',
    'radian',
    'ramanujan',
    'range',
    'rank',
    'ratio',
    'rational',
    'ray',
    'rectangle',
    'resultant',
    'rhombus',
    'riemann',
    'secant',
    'settheory',
    'shannon',
    'similarity',
    'sine',
    'slide',
    'solid',
    'span',
    'sphere',
    'square',
    'statistic',
    'statistics',
    'subspace',
    'surface',
    'symmetry',
    'tangent',
    'tensor',
    'tessellation',
    'tetrad',
    'thales',
    'theorem',
    'transformation',
    'transpose',
    'triangle',
    'trigonometry',
    'variable',
    'vector',
    'vertex',
    'web',

]
