HISTORY = [
    'age',
    'antiquity',
    'archeology',
    'archive',
    'artemis',
    'artifact',
    'aztec',
    'babylon',
    'battle',
    'beowulf',
    'biography',
    'bronzeage',
    'byzantium',
    'caesar',
    'calendar',
    'caligula',
    'castle',
    'censor',
    'century',
    'chronicle',
    'chronology',
    'churchill',
    'civilization',
    'classic',
    'cleopatra',
    'colonization',
    'columbus',
    'confucianism',
    'confucius',
    'conqueror',
    'conquest',
    'constantine',
    'constitution',
    'corinth',
    'crusades',
    'culture',
    'date',
    'dday',
    'democritus',
    'dickens',
    'dictator',
    'dictatorship',
    'diomedes',
    'dionysos',
    'document',
    'druid',
    'dynasty',
    'emperor',
    'empire',
    'epoch',
    'era',
    'eros',
    'expedition',
    'feudalism',
    'fortress',
    'glyphs',
    'goebbels',
    'heritage',
    'hippocrates',
    'historian',
    'history',
    'hitler',
    'homer',
    'iliad',
    'imperialism',
    'invasion',
    'ironage',
    'jefferson',
    'journal',
    'kennedy',
    'king',
    'kingdoms',
    'knight',
    'lancelot',
    'legion',
    'lenin',
    'lincoln',
    'lombards',
    'luther',
    'mandela',
    'manuscript',
    'marcopolo',
    'marx',
    'mesopotamia',
    'michelangelo',
    'midas',
    'monarchy',
    'mussolini',
    'mythology',
    'napoleon',
    'nero',
    'nietzsche',
    'nomad',
    'odin',
    'odysseus',
    'odyssey',
    'olympia',
    'orpheus',
    'ostracism',
    'palace',
    'pandora',
    'perseus',
    'pharaoh',
    'pocahontas',
    'pompeii',
    'poseidon',
    'prehistory',
    'provenance',
    'pyramids',
    'quaestor',
    'queen',
    'ragnar',
    'ragnarok',
    'rebellion',
    'reformation',
    'renaissance',
    'revolution',
    'rome',
    'roosevelt',
    'saga',
    'samurai',
    'sanskrit',
    'scripts',
    'seneca',
    'settlement',
    'shogun',
    'sparta',
    'spartacus',
    'sphinx',
    'stalin',
    'stoneage',
    'stonehenge',
    'sumerians',
    'sword',
    'tacitus',
    'temple',
    'thor',
    'time',
    'totalitarianism',
    'trade',
    'treaty',
    'troy',
    'tudor',
    'valhalla',
    'viking',
    'voltaire',
    'war',
    'warfare',
    'washington',

]
