FOOD = [
    'aroma',
    'asadero',
    'asiago',
    'bagel',
    'beans',
    'beer',
    'biscuit',
    'blue',
    'bread',
    'brick',
    'brie',
    'broth',
    'burger',
    'burrata',
    'burrito',
    'butter',
    'butterkase',
    'cake',
    'camembert',
    'candy',
    'caramel',
    'caviar',
    'cheddar',
    'cheese',
    'cheeseburger',
    'cheesesteak',
    'chili',
    'chimichanga',
    'chives',
    'chocolate',
    'chutney',
    'cider',
    'clubhouse',
    'cobbler',
    'cocoa',
    'coffee',
    'colby',
    'cookie',
    'cotija',
    'cousine',
    'cream',
    'croissant',
    'crumble',
    'cuisine',
    'curd',
    'dessert',
    'dish',
    'donut',
    'drink',
    'edam',
    'eggs',
    'emmentaler',
    'empanada',
    'enchilada',
    'entree',
    'feta',
    'filet',
    'fish',
    'flour',
    'fontina',
    'food',
    'fries',
    'garlic',
    'ginger',
    'glaze',
    'gorgonzola',
    'gouda',
    'grill',
    'hamburger',
    'havarti',
    'honey',
    'horseradish',
    'hotdog',
    'ice',
    'juice',
    'kasseri',
    'ketchup',
    'lard',
    'limburger',
    'liquor',
    'margarine',
    'marinade',
    'mascarpone',
    'mayo',
    'mayonnaise',
    'meat',
    'milk',
    'mint',
    'miso',
    'mousse',
    'mozzarella',
    'muenster',
    'muffin',
    'mushroom',
    'mustard',
    'noodle',
    'nugget',
    'nut',
    'oil',
    'olive',
    'omelette',
    'onion',
    'pan',
    'panini',
    'parmesan',
    'pasta',
    'paste',
    'pastry',
    'pepato',
    'pepper',
    'pesto',
    'pie',
    'pita',
    'pizza',
    'plate',
    'pot',
    'poutine',
    'pretzel',
    'provolone',
    'pudding',
    'queso',
    'raclette',
    'recipe',
    'relish',
    'remoulade',
    'reuben',
    'rice',
    'ricotta',
    'roll',
    'romano',
    'salad',
    'salsa',
    'sandwich',
    'sauce',
    'sauerkraut',
    'seasoning',
    'skillet',
    'slider',
    'soda',
    'sopapillas',
    'soup',
    'soy',
    'spice',
    'sriracha',
    'steak',
    'stew',
    'sugar',
    'sweets',
    'swiss',
    'syrup',
    'taco',
    'taquito',
    'tartar',
    'taste',
    'tea',
    'toast',
    'tostada',
    'vinegar',
    'waffle',
    'wasabi',
    'water',
    'wheat',
    'wine',
    'wok',
    'wrap',
    'yeast',
    'yogurt',

]
