ASTRONOMY = [
    'albattani',
    'andromeda',
    'antimatter',
    'aphelion',
    'apoapsis',
    'apogee',
    'apollo',
    'appulse',
    'aquarius',
    'asterism',
    'asteroid',
    'astrogeology',
    'astrometry',
    'astronaut',
    'astronomer',
    'astronomy',
    'austin',
    'barycenter',
    'bigbang',
    'blackbody',
    'blazar',
    'brightness',
    'capricornus',
    'centaur',
    'chromosphere',
    'comet',
    'conjunction',
    'constellation',
    'copernicus',
    'core',
    'corona',
    'cosmogony',
    'cosmology',
    'crater',
    'dust',
    'dwarf',
    'earth',
    'eclipse',
    'equinox',
    'exoplanet',
    'flux',
    'fusions',
    'galaxy',
    'galileo',
    'hadron',
    'halo',
    'heliosphere',
    'hubble',
    'hypergalaxy',
    'ionosphere',
    'isochrone',
    'jupiter',
    'kepler',
    'kuiperbelt',
    'lepton',
    'lonosphere',
    'luminosity',
    'lunar',
    'magnetosphere',
    'magnitude',
    'mars',
    'mercury',
    'meteor',
    'meteorite',
    'meteoroid',
    'micrometeoroid',
    'milkyway',
    'moon',
    'multiverse',
    'nasa',
    'nebula',
    'neptune',
    'neutrino',
    'nova',
    'observatory',
    'occultation',
    'omega',
    'opacity',
    'orbit',
    'orion',
    'parallax',
    'parsec',
    'penumbra',
    'perturbation',
    'photometry',
    'photosphere',
    'planet',
    'planetarium',
    'planetoid',
    'polaris',
    'protoplanet',
    'protostar',
    'pulsar',
    'quasar',
    'radius',
    'rainbow',
    'redshift',
    'relativity',
    'rocket',
    'rover',
    'sagittarius',
    'satellite',
    'saturn',
    'scintillation',
    'scorpius',
    'singularity',
    'sirius',
    'sky',
    'solstice',
    'space',
    'spacecraft',
    'star',
    'sun',
    'sunspot',
    'supercluster',
    'supernova',
    'telescope',
    'twilight',
    'universe',
    'uranus',
    'vacuum',
    'venus',
    'zenith',
    'zodiac',

]
