PHYSICS = [
    'aberration',
    'acceleration',
    'acre',
    'advection',
    'airwatt',
    'albedo',
    'ampere',
    'amplitude',
    'aperture',
    'atom',
    'bar',
    'baryon',
    'bhabha',
    'bifocal',
    'body',
    'bohr',
    'boltzmann',
    'booth',
    'candela',
    'capacitor',
    'celsius',
    'chain',
    'circuit',
    'conduction',
    'conductor',
    'convection',
    'coulomb',
    'crest',
    'current',
    'cyclotron',
    'dalton',
    'decibel',
    'density',
    'diffraction',
    'diffusion',
    'dioptre',
    'dispersion',
    'displacement',
    'distance',
    'distortion',
    'edison',
    'einstein',
    'electricity',
    'electron',
    'energy',
    'farad',
    'faraday',
    'feynman',
    'fields',
    'fluid',
    'force',
    'frequencies',
    'friction',
    'fusion',
    'gallon',
    'gram',
    'gravity',
    'heisenberg',
    'henry',
    'hertz',
    'impulse',
    'inch',
    'inertia',
    'insulator',
    'joule',
    'laser',
    'lens',
    'light',
    'lorentz',
    'lumen',
    'magnet',
    'magnification',
    'marconi',
    'maser',
    'masses',
    'matter',
    'meter',
    'mile',
    'mirror',
    'momentum',
    'neutron',
    'newton',
    'nucleus',
    'ohm',
    'optics',
    'ounce',
    'particle',
    'pascal',
    'period',
    'photon',
    'pint',
    'planck',
    'polarization',
    'positron',
    'potential',
    'pound',
    'power',
    'pressure',
    'prism',
    'projectile',
    'proton',
    'quanta',
    'quantum',
    'quark',
    'quart',
    'radiation',
    'reflection',
    'refraction',
    'resistivity',
    'resonance',
    'scalar',
    'scattering',
    'second',
    'shift',
    'solenoid',
    'spectrum',
    'speed',
    'strain',
    'stress',
    'tesla',
    'thrust',
    'ton',
    'torque',
    'trough',
    'velocity',
    'vibration',
    'volt',
    'volta',
    'voltage',
    'watt',
    'wave',
    'wavelength',
    'weight',
    'work',
    'yard',

]
