ANIMALS = [
    'aardvark',
    'aardwolf',
    'adder',
    'albatross',
    'alligator',
    'alpaca',
    'amberjack',
    'amphibian',
    'anaconda',
    'anchovy',
    'angelfish',
    'angler',
    'anglerfish',
    'angora',
    'ant',
    'anteater',
    'antelope',
    'antlion',
    'aotus',
    'ape',
    'aphid',
    'armadillo',
    'asp',
    'avocet',
    'ayu',
    'baboon',
    'badger',
    'balinese',
    'bandicoot',
    'barbel',
    'barnacle',
    'barracuda',
    'basilisk',
    'bat',
    'beagle',
    'bear',
    'beaver',
    'bedbug',
    'bee',
    'beetle',
    'bengal',
    'betta',
    'bird',
    'birman',
    'bison',
    'blackbird',
    'blowfish',
    'bluebird',
    'boa',
    'boar',
    'bobcat',
    'bobolink',
    'bobtail',
    'bocaccio',
    'boiga',
    'bombay',
    'bonobo',
    'booby',
    'boomslang',
    'borzoi',
    'bovid',
    'boxer',
    'budgie',
    'burbot',
    'burmese',
    'butterfly',
    'buzzard',
    'calico',
    'camel',
    'canary',
    'canid',
    'canidae',
    'capuchin',
    'capybara',
    'cardinal',
    'caribou',
    'carp',
    'cat',
    'caterpillar',
    'catfish',
    'catshark',
    'cattle',
    'centipede',
    'cephalopod',
    'chameleon',
    'cheetah',
    'chick',
    'chickadee',
    'chicken',
    'chimpanzee',
    'chinchilla',
    'chipmunk',
    'cicada',
    'clam',
    'clownfish',
    'cobra',
    'cockatiel',
    'cockatoo',
    'cockroach',
    'cod',
    'collie',
    'condor',
    'constrictor',
    'coot',
    'copperhead',
    'coral',
    'corgie',
    'cornsnake',
    'cougar',
    'covey',
    'cow',
    'coyote',
    'crab',
    'crane',
    'crawdad',
    'crayfish',
    'crocodile',
    'crow',
    'cuckoo',
    'dachshund',
    'damselfly',
    'darter',
    'deer',
    'diamondback',
    'dingo',
    'dinosaur',
    'dog',
    'dolphin',
    'donkey',
    'dormouse',
    'dove',
    'dragon',
    'dragonfly',
    'duck',
    'eagle',
    'earthworm',
    'earwig',
    'echidna',
    'eel',
    'egret',
    'elephant',
    'elk',
    'emu',
    'ermine',
    'falcon',
    'feist',
    'felidae',
    'ferret',
    'finch',
    'firefly',
    'fishes',
    'flamingo',
    'flea',
    'flounder',
    'fly',
    'flyingfish',
    'fowl',
    'fox',
    'frog',
    'galliform',
    'gamefowl',
    'gayal',
    'gazelle',
    'gecko',
    'gelada',
    'gerbil',
    'gibbon',
    'giraffe',
    'goat',
    'goldfinch',
    'goldfish',
    'goose',
    'gopher',
    'gorilla',
    'grasshopper',
    'grouper',
    'grouse',
    'guan',
    'guanaco',
    'guineafowl',
    'gull',
    'guppy',
    'haddock',
    'halibut',
    'hamster',
    'hare',
    'harrier',
    'hawk',
    'hedgehog',
    'heron',
    'herring',
    'himalayan',
    'hippopotamus',
    'hognose',
    'hookworm',
    'hornet',
    'horse',
    'hound',
    'hoverfly',
    'howler',
    'hummingbird',
    'husky',
    'hyena',
    'iguana',
    'impala',
    'indri',
    'jackal',
    'jackdaw',
    'jaguar',
    'javanese',
    'jay',
    'jellyfish',
    'junglefowl',
    'kangaroo',
    'kestrel',
    'kingfisher',
    'kite',
    'kiwibird',
    'koala',
    'koi',
    'korat',
    'krait',
    'krill',
    'ladybug',
    'lamprey',
    'lancehead',
    'landfowl',
    'langur',
    'lark',
    'leech',
    'lemming',
    'lemur',
    'leopard',
    'leopon',
    'limpet',
    'lion',
    'lizard',
    'llama',
    'lobster',
    'locust',
    'longhair',
    'loon',
    'loris',
    'louse',
    'lungfish',
    'lynx',
    'macaque',
    'macaw',
    'mackerel',
    'magpie',
    'maltese',
    'mamba',
    'mammal',
    'manatee',
    'mandrill',
    'marlin',
    'marmalade',
    'marmoset',
    'marmot',
    'marsupial',
    'marten',
    'martin',
    'mastodon',
    'meadowlark',
    'meerkat',
    'mink',
    'minnow',
    'mite',
    'mockingbird',
    'mole',
    'mollusk',
    'mongoose',
    'monkey',
    'moose',
    'mosquito',
    'moth',
    'mouse',
    'mule',
    'mullet',
    'muskox',
    'narwhal',
    'newt',
    'nightingale',
    'ocelot',
    'octopus',
    'opossum',
    'orangutan',
    'orca',
    'oriental',
    'osprey',
    'ostrich',
    'otter',
    'owl',
    'ox',
    'panda',
    'panther',
    'parakeet',
    'parrot',
    'parrotfish',
    'partridge',
    'peacock',
    'peafowl',
    'pelican',
    'penguin',
    'perch',
    'persian',
    'pheasant',
    'pig',
    'pigeon',
    'pike',
    'pinniped',
    'pinscher',
    'pintail',
    'piranha',
    'planarian',
    'platypus',
    'pollock',
    'pony',
    'poodle',
    'porcupine',
    'porpoise',
    'possum',
    'prawn',
    'primate',
    'ptarmigan',
    'puffin',
    'pug',
    'puma',
    'pythons',
    'quail',
    'quelea',
    'quetzal',
    'quokka',
    'rabbit',
    'raccoon',
    'rail',
    'rat',
    'rattlesnake',
    'raven',
    'razorbill',
    'reindeer',
    'retriever',
    'rhea',
    'rhinoceros',
    'roadrunner',
    'rodent',
    'rook',
    'rooster',
    'rottweiler',
    'roundworm',
    'sailfish',
    'salamander',
    'salmon',
    'sardine',
    'sawfish',
    'scallop',
    'schnauzer',
    'scorpion',
    'seahorse',
    'setter',
    'shark',
    'sheep',
    'shepherd',
    'shrew',
    'shrike',
    'shrimp',
    'siamese',
    'siberian',
    'silkworm',
    'silverfish',
    'skink',
    'skunk',
    'skylark',
    'sloth',
    'slug',
    'smelt',
    'snail',
    'snake',
    'snapper',
    'snipe',
    'sole',
    'spaniel',
    'sparrow',
    'spider',
    'spitz',
    'spoonbill',
    'squid',
    'squirrel',
    'starfish',
    'starling',
    'stingray',
    'stoat',
    'stork',
    'sturgeon',
    'swallow',
    'swan',
    'swift',
    'swordfish',
    'swordtail',
    'tabby',
    'tahr',
    'takin',
    'tamarin',
    'tanager',
    'tapir',
    'tarantula',
    'tarsier',
    'termite',
    'tern',
    'terrier',
    'thrush',
    'tick',
    'tiger',
    'tiglon',
    'tilapia',
    'toad',
    'tom',
    'tortoise',
    'toucan',
    'trout',
    'tuna',
    'turkeys',
    'turtle',
    'tyrannosaurus',
    'unicorn',
    'urial',
    'vicuna',
    'viper',
    'vole',
    'vulture',
    'wallaby',
    'walrus',
    'warbler',
    'wasp',
    'weasel',
    'westie',
    'whale',
    'whippet',
    'whitefish',
    'wildcat',
    'wildebeest',
    'wildfowl',
    'wolf',
    'wolverine',
    'wombat',
    'woodpecker',
    'worm',
    'wren',
    'yak',
    'zebra',

]
