PLANTS = [
    'acacia',
    'acorn',
    'agave',
    'alfalfa',
    'aloevera',
    'apple',
    'apricot',
    'ash',
    'aster',
    'avocado',
    'azalea',
    'bamboo',
    'banana',
    'bark',
    'basil',
    'bean',
    'begonia',
    'berry',
    'birch',
    'blade',
    'bleedingheart',
    'bluebell',
    'bonsai',
    'bougainvillea',
    'brush',
    'bud',
    'bulb',
    'bush',
    'cactus',
    'camellia',
    'cantaloupe',
    'carnation',
    'catnip',
    'cedar',
    'celosia',
    'chamomile',
    'cherry',
    'chrysanthemum',
    'citron',
    'citrus',
    'clematis',
    'clover',
    'coconut',
    'coralbells',
    'coreopsis',
    'cork',
    'corolla',
    'cosmos',
    'crocus',
    'cyclamen',
    'daffodil',
    'dahlia',
    'daisy',
    'dandelion',
    'delphinium',
    'echinacea',
    'elderberry',
    'fennel',
    'fern',
    'ficus',
    'fig',
    'flora',
    'forsythia',
    'foxglove',
    'freesia',
    'fruit',
    'garden',
    'gardenia',
    'geranium',
    'gladiolus',
    'goldenrod',
    'grain',
    'grape',
    'grass',
    'grove',
    'guava',
    'hellebore',
    'herb',
    'hibiscus',
    'holly',
    'honeysuckle',
    'hosta',
    'hyacinth',
    'hydrangea',
    'iris',
    'ivy',
    'jasmine',
    'juniper',
    'kelp',
    'kiwi',
    'kudzu',
    'lantana',
    'lavender',
    'lemon',
    'lilac',
    'lily',
    'lime',
    'lupin',
    'lupine',
    'magnolia',
    'mango',
    'maple',
    'marigold',
    'melon',
    'moss',
    'mulberry',
    'narcissus',
    'nasturtium',
    'nectar',
    'nectarine',
    'oak',
    'orange',
    'orchid',
    'palm',
    'pansy',
    'papaya',
    'peach',
    'pear',
    'peony',
    'petal',
    'petunia',
    'pine',
    'pineapple',
    'plum',
    'poinsettia',
    'poppy',
    'primrose',
    'prune',
    'quince',
    'raisin',
    'raspberry',
    'resin',
    'rhododendron',
    'rose',
    'rosemary',
    'rudbeckia',
    'sage',
    'salvia',
    'sedum',
    'shrub',
    'snapdragon',
    'snowdrop',
    'spiderplant',
    'spine',
    'sprout',
    'spruce',
    'stalk',
    'sunflower',
    'tangerine',
    'thorn',
    'thyme',
    'tree',
    'tulip',
    'twig',
    'vein',
    'vine',
    'violet',
    'weed',
    'wisteria',
    'yarrow',
    'yew',
    'yucca',
    'zinnia',

]
